==> bw-xml-synchws-4.0.7-sources.jar: ietf/params/xml/ns/icalendar_2/TextParameterType.java <==

package ietf.params.xml.ns.icalendar_2;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TextParameterType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TextParameterType">
 *   &lt;complexContent>
 *     &lt;extension base="{urn:ietf:params:xml:ns:icalendar-2.0}BaseParameterType">
 *       &lt;sequence>
 *         &lt;element ref="{urn:ietf:params:xml:ns:icalendar-2.0}text"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TextParameterType", propOrder = {
    "text"
})
@XmlSeeAlso({
    FmttypeParamType.class,
    TzidParamType.class,
    XBedeworkUidParamType.class,
    PartstatParamType.class,
    XBedeworkWrappedNameParamType.class,
    CutypeParamType.class,
    RoleParamType.class,
    ScheduleForceSendParamType.class,
    ReltypeParamType.class,
    FbtypeParamType.class,
    ScheduleStatusParamType.class,
    CnParamType.class,
    ScheduleAgentParamType.class,
    LanguageParamType.class,
    EncodingParamType.class,
    PublicCommentParameterType.class,
    RelatedParamType.class,
    XBedeworkLocKeyParamType.class
})
public class TextParameterType
    extends BaseParameterType
{

    @XmlElement(required = true)
    protected String text;

    /**
     * Gets the value of the text property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getText() {
        return text;
    }

    /**
     * Sets the value of the text property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setText(String value) {
        this.text = value;
    }

}

==> bw-xml-synchws-5.0.0-sources.jar: ietf/params/xml/ns/icalendar_2/TextParameterType.java <==

package ietf.params.xml.ns.icalendar_2;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TextParameterType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TextParameterType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{urn:ietf:params:xml:ns:icalendar-2.0}BaseParameterType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{urn:ietf:params:xml:ns:icalendar-2.0}text"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TextParameterType", propOrder = {
    "text"
})
@XmlSeeAlso({
    CnParamType.class,
    CutypeParamType.class,
    EncodingParamType.class,
    FmttypeParamType.class,
    FbtypeParamType.class,
    LanguageParamType.class,
    PartstatParamType.class,
    RelatedParamType.class,
    ReltypeParamType.class,
    RoleParamType.class,
    TzidParamType.class,
    ScheduleAgentParamType.class,
    ScheduleForceSendParamType.class,
    ScheduleStatusParamType.class,
    PublicCommentParameterType.class,
    XBedeworkUidParamType.class,
    XBedeworkLocKeyParamType.class,
    XBedeworkWrappedNameParamType.class
})
public class TextParameterType
    extends BaseParameterType
{

    @XmlElement(required = true)
    protected String text;

    /**
     * Gets the value of the text property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getText() {
        return text;
    }

    /**
     * Sets the value of the text property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setText(String value) {
        this.text = value;
    }

}
